* v0.2.3, 2014-02-16 --- Fixed installation via pip
* v0.2.2, 2014-01-15 --- Possibility to use user-defined session
* v0.2.1, 2014-01-14 --- Added implicit delay value
* v0.2.0, 2014-01-04 --- Reorganization of modules and documentation
* v0.1.1, 2013-12-31 --- Previous release was not working
* v0.1.0, 2013-12-30 --- Initial release
